#' Consensus clustering by Mirkin based methods
#' 
#' @param listpart a list of partitions
#' @param method a single string specifying the mirkin based method used. Available methods are "saom" and "bok". Default value is "saom".
#' @param threshold a integer specifying when the algorithm is stoped (only used for method= "saom")
#' @param printflag a boolean. If TRUE, mirkin will print messages on console (only used for method= "saom")
#' @keywords internal


mirkin<-function(listpart,method="saom",threshold=NULL,printflag=TRUE){
  if(length(listpart)==1){
    res<-listpart[[1]]
    return(res)
  }
  
  if(method%in%c("bok","saom")){
    mat<-usedist::dist_make(do.call(rbind,listpart),distance_fcn=mirkin.intern)
    
    critmirkin<-colSums(sapply(seq(length(listpart)),
                               FUN=function(xx,mat,listpart){usedist::dist_get(mat, xx,seq(length(listpart))[-xx])},mat=mat,listpart=listpart))
    
    if(method=="bok"){
      return(listpart[[which.min(critmirkin)]])
    }else if(method=="saom"){
      partinit<-listpart[[which.min(critmirkin)]]#initialisation par la partition bok
      kk<-length(unique(partinit))##nombre de blocs
      if(is.null(threshold)){mythreshold<-length(partinit)*(kk+1)}else{mythreshold<-threshold}#nombre d'itérations
      R<-matrix(0,length(listpart[[1]]),length(listpart[[1]]))#matrice d'adjacence rempli de 0
      for(ii in length(listpart)){
        R<-R+tcrossprod(FactoMineR::tab.disjonctif(listpart[[ii]]))#somme de toutes les matrices d'adjacences
      }
      
      
      
      
      compt<-1
      while(compt<mythreshold){
        x<-sample(seq(length(partinit)),size=1)#tirage d'une observation
        bloca<-which(partinit==partinit[x])#identification des individus dans la même classe que x
        bloca<-bloca[-which(bloca==x)]#on enleve x de la liste
        indexblocb<-sample(seq(kk+1)[-partinit[x]],size=1)#on tire un bloc au hasard, différent de celui de x et potentiellement nouveau
        
        blocb<-which(partinit==indexblocb)
        
        #methode brute
        partinittmp<-partinit
        partinittmp[x]<-indexblocb
        newcrit<-sum(usedist::dist_get(usedist::dist_make(rbind(do.call(rbind,listpart),partinittmp),distance_fcn=mirkin.intern),(length(listpart)+1),seq(length(listpart))))
        oldcrit<-sum(usedist::dist_get(usedist::dist_make(rbind(do.call(rbind,listpart),partinit),distance_fcn=mirkin.intern),(length(listpart)+1),seq(length(listpart))))
        if (newcrit<oldcrit){
          # print("TRUE")
          partinit[x]<-indexblocb
          kk<-length(unique(partinit))
          compt<-1
        }else{compt<-compt+1}
        if(printflag){print(compt)}
        
        # if(length(bloca)>0){
        #   term1<-sum(length(listpart)-2*R[x,bloca])
        # }else{
        #   term1<-0
        # }
        # if(indexblocb==(kk+1)){
        #   term2<-0
        # }else{
        #   term2<-sum(length(listpart)-2*R[x,blocb])
        # }
        # 
        # 
        # 
        # delta<- term1-term2
        # 
        # if(delta<0){
        #   partinit[x]<-indexblocb
        #   kk<-length(unique(partinit))
        #   compt<-1
        # }else{compt<-compt+1}
        # print(compt)
      }
      
      return(partinit)
      
    }
  }
}