% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/clusterMI-package.R
\docType{package}
\name{clusterMI-package}
\alias{clusterMI-package}
\title{clusterMI: Cluster analysis with missing values by multiple imputation}
\description{
\code{clusterMI} is a package to perform clustering with missing values. For achieving this goal, multiple imputation is used.
The package offers various multiple imputation methods dedicated to clustered individuals (Audigier et al. 2021).
In addition, it allows pooling results both in terms of partition and instability (Audigier and Niang, 2020). Among applications, such functionalities can be used to choose a number of clusters with missing values
}
\examples{
data(wine)

require(parallel)
set.seed(123456)
ref <- wine$cult
nb.clust <- 3
wine.na <- wine
wine.na$cult <- NULL
wine.na <- as.matrix(wine.na)
wine.na[sample(seq(length(wine.na)), size = ceiling(length(wine.na)/3))] <- NA

# imputation
m <- 5 # number of imputed data sets. Should be larger in practice
res.imp <- imputedata(data.na = wine.na, method = "FCS-homo", nb.clust = nb.clust, m = m)

# pooling
nnodes <- 2 # Number of CPU cores for parallel computing
res.pool <- clusterMI(res.imp, nnodes = nnodes)

res.pool$instability
table(ref, res.pool$part)

\donttest{
# choice of nb.clust

res.nbclust <- choosenbclust(res.pool)
}

}
\references{
Audigier, V. and Niang, N. Clustering with missing data: which equivalent for Rubin's rules? ArXiv e-prints <arXiv:2011.13694>, 2020

 Bar-Hen, A. and Audigier, V., An ensemble learning method for variable selection: application to high dimensional data and missing values, ArXiv e-prints <arXiv:1808.06952>, 2018.

 Fang, Y. and Wang, J., Selection of the number of clusters via the bootstrap method. Computational Statistics and Data Analysis, 56, 468-477 <doi:10.1016/j.csda.2011.09.003> 2012.
}
